#!/usr/bin/env python
# coding: utf-8

import os, sys, time, argparse, shutil


def manage_console():
    parser = argparse.ArgumentParser()

    parser.add_argument('-project', '-startproject', '-p', type=str, help='Create project' )
    parser.add_argument('-app', '-startapp', '-a',         type=str, help='Create app'     )
    args = parser.parse_args()

    print( 'args.project', args.project)

    path_root = os.path.dirname(__file__)

    if '/core' in path_root:
        path_root = path_root[:-5]
    else:
        __import__('tao1')
        module = sys.modules['tao1']
        path_root = os.path.dirname(os.path.abspath(module.__file__))

    print ( 'path1', path_root )
    if args.project is not None:
        shutil.copytree(  os.path.join( path_root , 'sites', 'daoerp'), os.path.join( str(args.project) ) )
        set_file = """
    #!/usr/bin/env python
    # coding: utf-8

    #debug = True
    debug = False

    root = '%s'

    database={"login":"admin", "pass":"test_passwd", "host":["127.0.0.1:27017"], "port":"", 'name':'test'}
        """ % path_root

        with open(os.path.join( str(args.project) , 'settings.py'), 'w') as f: f.write(set_file)
    elif args.app != None:
        shutil.copytree( os.path.join( path_root, 'apps', 'app'), os.path.join( str(args.app) ) )

    print( args )























# os.mkdir('/backups2/')
# import shutil
# shutil.copytree('/home/smirnov/test', '/home/smirnov/wsd/test')



# set_file = """
# 	import os, sys
# 	sys.path.append('/home/user/workspace/django/dj')
# 	os.environ['DJANGO_SETTINGS_MODULE'] = 'dj.settings'
# 	import django.core.handlers.wsgi
# 	application = django.core.handlers.wsgi.WSGIHandler()
# """
# with open(os.path.join(pr_path, prog_name, 'settings.py'), 'w') as f: f.write(set_file)




#working_dir='/home/user/dev/tao1/sites/daoerp'
#python='/usr/bin/python3.4'
#pythonpath=/usr/local/lib/python3.4/dist-packages

worker_class ='aiohttp.worker.GunicornWebWorker'
bind='127.0.0.1:6677'
workers=8
reload=True
user = "nobody"

#        'app.app',    


#!/usr/bin/env python
# coding: utf-8

debug = True
debug = False

root = '/home/user/dev/tao1'

database={"login":"admin", "pass":"Gthcgtrnbdf", "host":["127.0.0.1:27017"], "port":"", 'name':'daoerp'}
# database={"login":"test", "pass":"passwd", "host":["127.0.0.1:27017"], 'name':'test'}


#!/usr/bin/env python
# coding: utf-8

# from app.user_site import *
# from app.perm.perm import *
# from app.tree.tree import *

import asyncio
import aiohttp_jinja2
import jinja2


#@asyncio.coroutine
#def page(request):
#	return templ('apps.app:index', request, {'key':'val'})


#@asyncio.coroutine
#def page2(request):
#	return templ('index', request, {'key':'val'})


































# coding: utf-8
from apps.app.view import  *
# from sites.daoerp.apps.app.view import  *
from core.union import route

# routes = [
route( '/',         page,				'GET', 'page' )
route( '/db',       test_db,			'GET', 'test_db' )

route( '/ws',       ws,					'GET', 'ws' )
route( '/wsh',      ws_handler,			'GET', 'ws_handler' )

# route( '/page',   page2,	'GET' )
# ]

# routes = {
	# 'old_doc_blog10':  		('/rss.xml',					        get_rss,			'GET'),
	# 'rss':					('/rss',						        get_rss,			'GET'),
	# 'scripts':				('/scripts/',						    get_list_informer,	'GET'),
	# 'scripts1':				('/scripts',						    get_list_informer,	'GET'),
# }






#!/usr/bin/env python
# coding: utf-8

import os, time
import asyncio

from pymongo import *
from gridfs import GridFS

import settings



def die(mess):
	raise Exception(str(mess))



# @asyncio.coroutine
# def server_connect():
# 	if not db_conn['conn']:
# 		db = get_settings('database', {} )
# 		kw = {}
# 		if 'rs' in db: kw['replicaSet'] = db['rs']
# 		db_conn['conn'] = MongoClient(db['host'], **kw)
# 	return db_conn['conn']

# @asyncio.coroutine
# def connect():
#     db = get_settings('database', {} )
#     kw = {}
#     if 'rs' in db: kw['replicaSet'] = db['rs']

#     mongo = MongoClient(db['host'], 27017)
#     print( mongo)
#     db = mongo['tok']
#     db.authenticate('admin', settings.database['pass'] )
#     return db


@asyncio.coroutine
def get_settings(name, def_val=None):
	if name in settings.__dict__: return settings.__dict__[name]
	else: return def_val


@asyncio.coroutine
def locale_date(format, dt, loc = 'en_US.UTF-8'):
	""" dt - кортеж """
	import locale
	lc = locale.getdefaultlocale()
	# lc = locale.getlocale(locale.LC_ALL)
	locale.setlocale(locale.LC_ALL, loc)
	res = time.strftime(format, dt)
	locale.setlocale(locale.LC_ALL, lc)
	return res



#!/usr/bin/env python
# coding: utf-8

# from app.user_site import *
# from app.perm.perm import *
# from app.tree.tree import *

import sys, os
import asyncio
import aiohttp_jinja2
import jinja2
from aiohttp import web
from aiohttp.web import Application, Response, MsgType, WebSocketResponse

# from core.utils import connect
from pymongo import *
from gridfs import GridFS
from aiohttp_session import get_session
import time
# print (sys.path) 

# from core.utils import *


@asyncio.coroutine
def test_db(request):
    print( 'bbbbbbbbbbbbbb' )

    session = yield from get_session(request)
    session['last_visit'] = time.time()
    request.db.doc.save({"_id":"test", "val":"test_db", "status":"success"})
    val = request.db.doc.find_one({"_id":"test"})
    return templ('apps.app:db_test', request, {'key':val})


# @asyncio.coroutine
def page(request):
	return templ('apps.app:index', request, {'key':'val'})

@asyncio.coroutine
def ws(request):
	return templ('apps.app:chat', request, {} )

@asyncio.coroutine
def ws_handler(request):
    print ('111111', request.scheme )
    ws = web.WebSocketResponse()
    ws.start(request)
    while True:
        print ('while' )
        msg = yield from ws.receive()
        print ('post while', msg )
        print('text')
        # print('text', aiohttp.MsgType.text)
        if msg.tp == MsgType.text:
            print ('1if', msg )
            if msg.data == 'close':
                print ('if', msg )
                yield from ws.close()
            else:
                print ('else', msg )
                ws.send_str(msg.data + '/answer')
        elif msg.tp == aiohttp.MsgType.close: print('websocket connection closed')
        elif msg.tp == aiohttp.MsgType.error: print('ws connection closed with exception %s', ws.exception())
    return ws	


# @asyncio.coroutine
# def page2(request):
	# return templ('./user_app/users_app/index.tpl', request, {'key':'val'})
	# return templ('index', request, {'key':'val'})

	

@asyncio.coroutine
def test_db1(request):
    # db = connect()
    # print( 'db' )

    # mongo = MongoClient('localhost', 27017)
    # print( mongo)
    # db = mongo['tok']
    # db.authenticate('admin', 'Gthcgtrnbdf')

    # print( db )
    # val = db['doc'].find_one({})

    # val = yield from request.db.doc.find_one({})
    val = request.db.doc.find_one({})
    # val = request['db'].doc.find_one({})
    return templ('apps.app:db_test', request, {'key':val})



























